@@ -90,7 +90,7 @@ class PaginatedListBase:
 
 class PaginatedList(PaginatedListBase):
     """
-    This class abstracts the `pagination of the API <http://developer.github.com/v3/#pagination>`_.
+    This class abstracts the `pagination of the API <https://docs.github.com/en/rest/guides/traversing-with-pagination>`_.
 
     You can simply enumerate through instances of this class::
 
@@ -153,6 +153,8 @@ class PaginatedList(PaginatedListBase):
                 if data and "total_count" in data:
                     self.__totalCount = data["total_count"]
                 elif data:
+                    if isinstance(data, dict):
+                        data = data[self.__list_item]
                     self.__totalCount = len(data)
                 else:
                     self.__totalCount = 0
