@@ -51,6 +51,7 @@
 ################################################################################
 
 import base64
+import datetime
 import json
 import logging
 import mimetypes
@@ -62,7 +63,10 @@ from io import IOBase
 
 import requests
 
-from . import Consts, GithubException
+from . import Consts, GithubException, GithubIntegration
+
+# For App authentication, time remaining before token expiration to request a new one
+ACCESS_TOKEN_REFRESH_THRESHOLD_SECONDS = 20
 
 
 class RequestsResponse:
@@ -82,7 +86,14 @@ class RequestsResponse:
 class HTTPSRequestsConnectionClass:
     # mimic the httplib connection object
     def __init__(
-        self, host, port=None, strict=False, timeout=None, retry=None, **kwargs
+        self,
+        host,
+        port=None,
+        strict=False,
+        timeout=None,
+        retry=None,
+        pool_size=None,
+        **kwargs,
     ):
         self.port = port if port else 443
         self.host = host
@@ -90,11 +101,23 @@ class HTTPSRequestsConnectionClass:
         self.timeout = timeout
         self.verify = kwargs.get("verify", True)
         self.session = requests.Session()
-        # Code to support retries
-        if retry:
+
+        if retry is None:
+            self.retry = requests.adapters.DEFAULT_RETRIES
+        else:
             self.retry = retry
-            self.adapter = requests.adapters.HTTPAdapter(max_retries=self.retry)
-            self.session.mount("https://", self.adapter)
+
+        if pool_size is None:
+            self.pool_size = requests.adapters.DEFAULT_POOLSIZE
+        else:
+            self.pool_size = pool_size
+
+        self.adapter = requests.adapters.HTTPAdapter(
+            max_retries=self.retry,
+            pool_connections=self.pool_size,
+            pool_maxsize=self.pool_size,
+        )
+        self.session.mount("https://", self.adapter)
 
     def request(self, verb, url, input, headers):
         self.verb = verb
@@ -122,7 +145,14 @@ class HTTPSRequestsConnectionClass:
 class HTTPRequestsConnectionClass:
     # mimic the httplib connection object
     def __init__(
-        self, host, port=None, strict=False, timeout=None, retry=None, **kwargs
+        self,
+        host,
+        port=None,
+        strict=False,
+        timeout=None,
+        retry=None,
+        pool_size=None,
+        **kwargs,
     ):
         self.port = port if port else 80
         self.host = host
@@ -130,11 +160,23 @@ class HTTPRequestsConnectionClass:
         self.timeout = timeout
         self.verify = kwargs.get("verify", True)
         self.session = requests.Session()
-        # Code to support retries
-        if retry:
+
+        if retry is None:
+            self.retry = requests.adapters.DEFAULT_RETRIES
+        else:
             self.retry = retry
-            self.adapter = requests.adapters.HTTPAdapter(max_retries=self.retry)
-            self.session.mount("http://", self.adapter)
+
+        if pool_size is None:
+            self.pool_size = requests.adapters.DEFAULT_POOLSIZE
+        else:
+            self.pool_size = pool_size
+
+        self.adapter = requests.adapters.HTTPAdapter(
+            max_retries=self.retry,
+            pool_connections=self.pool_size,
+            pool_maxsize=self.pool_size,
+        )
+        self.session.mount("http://", self.adapter)
 
     def request(self, verb, url, input, headers):
         self.verb = verb
@@ -256,37 +298,46 @@ class Requester:
         login_or_token,
         password,
         jwt,
+        app_auth,
         base_url,
         timeout,
-        client_id,
-        client_secret,
         user_agent,
         per_page,
         verify,
         retry,
+        pool_size,
     ):
         self._initializeDebugFeature()
 
+        self.__installation_authorization = None
+        self.__app_auth = app_auth
+        self.__base_url = base_url
+
         if password is not None:
             login = login_or_token
-            self.__authorizationHeader = "Basic " + base64.b64encode(
-                (login + ":" + password).encode("utf-8")
-            ).decode("utf-8").replace("\n", "")
+            b64 = (
+                base64.b64encode((f"{login}:{password}").encode())
+                .decode("utf-8")
+                .replace("\n", "")
+            )
+            self.__authorizationHeader = f"Basic {b64}"
         elif login_or_token is not None:
             token = login_or_token
-            self.__authorizationHeader = "token " + token
+            self.__authorizationHeader = f"token {token}"
         elif jwt is not None:
-            self.__authorizationHeader = "Bearer " + jwt
+            self.__authorizationHeader = f"Bearer {jwt}"
+        elif self.__app_auth is not None:
+            self._refresh_token()
         else:
             self.__authorizationHeader = None
 
-        self.__base_url = base_url
         o = urllib.parse.urlparse(base_url)
         self.__hostname = o.hostname
         self.__port = o.port
         self.__prefix = o.path
         self.__timeout = timeout
         self.__retry = retry  # NOTE: retry can be either int or an urllib3 Retry object
+        self.__pool_size = pool_size
         self.__scheme = o.scheme
         if o.scheme == "https":
             self.__connectionClass = self.__httpsConnectionClass
@@ -301,16 +352,48 @@ class Requester:
 
         self.oauth_scopes = None
 
-        self.__clientId = client_id
-        self.__clientSecret = client_secret
-
         assert user_agent is not None, (
             "github now requires a user-agent. "
-            "See http://developer.github.com/v3/#user-agent-required"
+            "See https://docs.github.com/en/rest/overview/resources-in-the-rest-api#user-agent-required"
         )
         self.__userAgent = user_agent
         self.__verify = verify
 
+    def _must_refresh_token(self) -> bool:
+        """Check if it is time to refresh the API token gotten from the GitHub app installation"""
+        if not self.__installation_authorization:
+            return False
+        return (
+            self.__installation_authorization.expires_at
+            < datetime.datetime.utcnow()
+            + datetime.timedelta(seconds=ACCESS_TOKEN_REFRESH_THRESHOLD_SECONDS)
+        )
+
+    def _get_installation_authorization(self):
+        assert self.__app_auth is not None
+        integration = GithubIntegration.GithubIntegration(
+            self.__app_auth.app_id,
+            self.__app_auth.private_key,
+            base_url=self.__base_url,
+        )
+        return integration.get_access_token(
+            self.__app_auth.installation_id,
+            permissions=self.__app_auth.token_permissions,
+        )
+
+    def _refresh_token_if_needed(self) -> None:
+        """Get a new access token from the GitHub app installation if the one we have is about to expire"""
+        if not self.__installation_authorization:
+            return
+        if self._must_refresh_token():
+            logging.debug("Refreshing access token")
+            self._refresh_token()
+
+    def _refresh_token(self) -> None:
+        """In the context of a GitHub app, refresh the access token"""
+        self.__installation_authorization = self._get_installation_authorization()
+        self.__authorizationHeader = f"token {self.__installation_authorization.token}"
+
     def requestJsonAndCheck(self, verb, url, parameters=None, headers=None, input=None):
         return self.__check(
             *self.requestJson(
@@ -354,11 +437,17 @@ class Requester:
             ):  # issue80
                 if o.scheme == "http":
                     cnx = self.__httpConnectionClass(
-                        o.hostname, o.port, retry=self.__retry
+                        o.hostname,
+                        o.port,
+                        retry=self.__retry,
+                        pool_size=self.__pool_size,
                     )
                 elif o.scheme == "https":
                     cnx = self.__httpsConnectionClass(
-                        o.hostname, o.port, retry=self.__retry
+                        o.hostname,
+                        o.port,
+                        retry=self.__retry,
+                        pool_size=self.__pool_size,
                     )
         return cnx
 
@@ -386,7 +475,7 @@ class Requester:
             cls = GithubException.UnknownObjectException
         else:
             cls = GithubException.GithubException
-        return cls(status, output)
+        return cls(status, output, headers)
 
     def __structuredFromJson(self, data):
         if len(data) == 0:
@@ -397,6 +486,8 @@ class Requester:
             try:
                 return json.loads(data)
             except ValueError:
+                if data.startswith("{") or data.startswith("["):
+                    raise
                 return {"data": data}
 
     def requestJson(
@@ -416,14 +507,12 @@ class Requester:
 
             encoded_input = ""
             for name, value in input.items():
-                encoded_input += "--" + boundary + eol
-                encoded_input += (
-                    'Content-Disposition: form-data; name="' + name + '"' + eol
-                )
+                encoded_input += f"--{boundary}{eol}"
+                encoded_input += f'Content-Disposition: form-data; name="{name}"{eol}'
                 encoded_input += eol
                 encoded_input += value + eol
-            encoded_input += "--" + boundary + "--" + eol
-            return "multipart/form-data; boundary=" + boundary, encoded_input
+            encoded_input += f"--{boundary}--{eol}"
+            return f"multipart/form-data; boundary={boundary}", encoded_input
 
         return self.__requestEncode(cnx, verb, url, parameters, headers, input, encode)
 
@@ -534,9 +623,7 @@ class Requester:
         return status, responseHeaders, output
 
     def __authenticate(self, url, requestHeaders, parameters):
-        if self.__clientId and self.__clientSecret and "client_id=" not in url:
-            parameters["client_id"] = self.__clientId
-            parameters["client_secret"] = self.__clientSecret
+        self._refresh_token_if_needed()
         if self.__authorizationHeader is not None:
             requestHeaders["Authorization"] = self.__authorizationHeader
 
@@ -544,7 +631,7 @@ class Requester:
         # URLs generated locally will be relative to __base_url
         # URLs returned from the server will start with __base_url
         if url.startswith("/"):
-            url = self.__prefix + url
+            url = f"{self.__prefix}{url}"
         else:
             o = urllib.parse.urlparse(url)
             assert o.hostname in [
@@ -557,14 +644,14 @@ class Requester:
             assert o.port == self.__port
             url = o.path
             if o.query != "":
-                url += "?" + o.query
+                url += f"?{o.query}"
         return url
 
     def __addParametersToUrl(self, url, parameters):
         if len(parameters) == 0:
             return url
         else:
-            return url + "?" + urllib.parse.urlencode(parameters)
+            return f"{url}?{urllib.parse.urlencode(parameters)}"
 
     def __createConnection(self):
         kwds = {}
@@ -575,7 +662,11 @@ class Requester:
             return self.__connection
 
         self.__connection = self.__connectionClass(
-            self.__hostname, self.__port, retry=self.__retry, **kwds
+            self.__hostname,
+            self.__port,
+            retry=self.__retry,
+            pool_size=self.__pool_size,
+            **kwds,
         )
 
         return self.__connection
@@ -584,17 +675,18 @@ class Requester:
         if self.__logger is None:
             self.__logger = logging.getLogger(__name__)
         if self.__logger.isEnabledFor(logging.DEBUG):
+            headersForRequest = requestHeaders.copy()
             if "Authorization" in requestHeaders:
                 if requestHeaders["Authorization"].startswith("Basic"):
-                    requestHeaders[
+                    headersForRequest[
                         "Authorization"
                     ] = "Basic (login and password removed)"
                 elif requestHeaders["Authorization"].startswith("token"):
-                    requestHeaders["Authorization"] = "token (oauth token removed)"
+                    headersForRequest["Authorization"] = "token (oauth token removed)"
                 elif requestHeaders["Authorization"].startswith("Bearer"):
-                    requestHeaders["Authorization"] = "Bearer (jwt removed)"
+                    headersForRequest["Authorization"] = "Bearer (jwt removed)"
                 else:  # pragma no cover (Cannot happen, but could if we add an authentication method => be prepared)
-                    requestHeaders[
+                    headersForRequest[
                         "Authorization"
                     ] = "(unknown auth removed)"  # pragma no cover (Cannot happen, but could if we add an authentication method => be prepared)
             self.__logger.debug(
@@ -603,7 +695,7 @@ class Requester:
                 self.__scheme,
                 self.__hostname,
                 url,
-                requestHeaders,
+                headersForRequest,
                 input,
                 status,
                 responseHeaders,
